package com.willalp.web.controller.system;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import com.willalp.common.core.domain.entity.SysRole;
import com.willalp.system.domain.SysUserOrganization;
import com.willalp.system.service.ISysRoleService;
import com.willalp.system.service.ISysUserOrganizationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.willalp.common.constant.Constants;
import com.willalp.common.core.domain.AjaxResult;
import com.willalp.common.core.domain.entity.SysMenu;
import com.willalp.common.core.domain.entity.SysUser;
import com.willalp.common.core.domain.model.LoginBody;
import com.willalp.common.utils.SecurityUtils;
import com.willalp.framework.web.service.SysLoginService;
import com.willalp.framework.web.service.SysPermissionService;
import com.willalp.system.service.ISysMenuService;

/**
 * 登录验证
 *
 * @author willalp
 */
@RestController
public class SysLoginController
{
    @Autowired
    private SysLoginService loginService;

    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private ISysRoleService iSysRoleService;

    @Autowired
    private ISysUserOrganizationService iSysUserOrganizationService;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo()
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);
        ajax.put("roleTypes", iSysRoleService.queryRoleTypeByLoginName(user.getUserName()));
        SysUserOrganization org = new SysUserOrganization();
        org.setLoginName(user.getUserName());
        List<SysUserOrganization> organizations = iSysUserOrganizationService.selectSysUserOrganizationList(org);
        ajax.put("organizations", organizations.stream().map(SysUserOrganization::getOrganizationCode).collect(Collectors.toSet()));
        organizations = organizations.stream().filter(o -> o.getIsDefault() == 1).collect(Collectors.toList());
        ajax.put("organ", organizations.get(0).getOrganizationCode());
        return ajax;
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        Long userId = SecurityUtils.getUserId();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(userId);
        return AjaxResult.success(menuService.buildMenus(menus));
    }
}
