package com.willalp.yiqing.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.willalp.common.annotation.Excel;
import com.willalp.common.core.domain.BaseEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 阳性及密接人员对象 hs_yiqing_positive_contiguity_user
 *
 * @author willalp
 * @date 2022-05-15
 */

@EqualsAndHashCode(callSuper = true)
@Data
@TableName("hs_yiqing_positive_contiguity_user")
public class HsPositiveContiguityUser extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 人员核酸记录
     */
    @TableField(exist = false)
    List<HsYiqingRnsResult> rnsResults = new ArrayList<>();

    /**
     * 核酸结果
     */
    @TableField(exist = false)
    private String rnaResult;

    /**
     * list类型（所以人员/居家人员）
     */
    @TableField(exist = false)
    private int listType;

    /**
     * 主键
     */
    @TableId
    private String dataId;

    /**
     * 编号
     */
    @Excel(name = "编号")
    private String userNo;

    /**
     * 异常登记时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "异常登记时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date exceptionRegisterTime;

    /**
     * 异常登记类型(1=阳性,2=密接,3=密接,4=复阳,5=正常,6=治愈,7=失联,8=死亡,9=其它)
     */
    @Excel(name = "异常类型", readConverterExp = "1=阳性,2=密接,3=次密接,4=复阳,5=正常,6=阳性治愈,7=失联,8=死亡,9=其它")
    private String exceptionRegisterType;
    /**
     * 最新状态(1=阳性,2=密接,3=密接,4=复阳,5=正常,6=治愈,7=失联,8=死亡,9=其它)
     */
    @Excel(name = "最新状态", readConverterExp = "1=阳性,2=密接,3=次密接,4=复阳,5=正常,6=阳性治愈,7=失联,8=死亡,9=其它")
    private String normalStatus;

    /**
     * 当前隔离方式(1=居家隔离,2=阳性集中隔离,3=密接集中隔离,4=解除隔离,5=失联,6=其他)
     */
    @Excel(name = "当前隔离方式", readConverterExp = "1=居家隔离,2=阳性集中隔离,3=密接集中隔离,4=解除隔离,5=失联,6=其他")
    private String transferType;

    /**
     * 出隔离时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "出隔离时间", width = 15, dateFormat = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date normalTime;

    /**
     * 解除管控时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    @Excel(name = "解除管控时间", width = 15, dateFormat = "yyyy-MM-dd")
    private Date transferTime;

    /**
     * 姓名
     */
    @Excel(name = "姓名")
    private String userName;

    /**
     * 证件类型
     */
    @Excel(name = "证件类型", readConverterExp = "0=身份证,1=社保卡,2=军官证,3=护照,4=港澳通行证,5=其他")
    private String otherAttest;

    /**
     * 证件号
     */
    @Excel(name = "证件号")
    private String attestNo;

    /**
     * 联系电话
     */
    @Excel(name = "个人电话")
    private String phone;

    /**
     * 居住地址
     */
    @Excel(name = "居住地址")
    private String address;

    /**
     * 所属地区
     */
    @Excel(name = "属地/社区")
    private String areaName;

    /**
     * 居委
     */
    @Excel(name = "居委")
    private String houseNo;


    /**
     * 姓名
     */
    @Excel(name = "联系人")
    private String belongName;

    /**
     * 联系电话
     */
    @Excel(name = "联系电话")
    private String belongPhone;

    /**
     * 备注
     */
    @Excel(name = "备注")
    private String remark;

    /**
     * 7天派单
     */
    private String sevenSendOrders;

    /**
     * 14天派单
     */
    private String fourteenSendOrders;

    /**
     * 是否删除（0.未删除；1.已删除）
     */
    @TableLogic
    private Integer isDelete;

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("dataId", getDataId())
                .append("userNo", getUserNo())
                .append("userName", getUserName())
                .append("otherAttest", getOtherAttest())
                .append("attestNo", getAttestNo())
                .append("phone", getPhone())
                .append("address", getAddress())
                .append("houseNo", getHouseNo())
                .append("areaName", getAreaName())
                .append("isDelete", getIsDelete())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .append("remark", getRemark())
                .toString();
    }
}
