package com.willalp.device.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.willalp.common.core.domain.entity.SysUser;
import com.willalp.device.domain.Device;
import com.willalp.device.domain.vo.DeviceInitVo;

import java.util.List;

/**
 * deviceService接口
 *
 * @author willalp
 * @date 2021-11-23
 */
public interface IDeviceService extends IService<Device> {
    /**
     * 查询device列表
     *
     * @param device device
     * @return device集合
     */
    public List<Device> selectDeviceList(Device device);


    /**
     * 初始化设备
     *
     * @param deviceInitVo
     * @return
     */
    String deviceInit(DeviceInitVo deviceInitVo);

    /**
     * 根据设备ID获取用户ID并组成用户信息列表
     *
     * @param deviceId
     * @return
     */
    List<SysUser> getDeviceBindingUsers(String deviceId);

    /**
     * 根据用户类型 会控APP用户列表
     *
     * @param userType
     * @return
     */
    List<SysUser> selectAllUserList(String userType);

    /**
     * 设备用户绑定
     *
     * @param deviceId
     * @param userId
     * @return
     */
    int bindingUser(String deviceId, String userId);

    /**
     * 设备用户解绑
     *
     * @param deviceId
     * @param userId
     * @return
     */
    int untieUser(String deviceId, String userId);

}
