package com.willalp.level.service.impl;

import com.willalp.common.core.service.impl.TreeCommonServiceImpl;
import com.willalp.level.domain.HsSysLevel;
import com.willalp.level.mapper.HsSysLevelMapper;
import com.willalp.level.service.IHsSysLevelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 层级规则Service业务层处理
 *
 * @author bjh
 * @date 2021-12-02
 */
@Service
public class HsSysLevelServiceImpl extends TreeCommonServiceImpl<HsSysLevelMapper, HsSysLevel> implements IHsSysLevelService
{
    @Autowired
    private HsSysLevelMapper hsSysLevelMapper;

    /**
     * 查询层级规则
     *
     * @param id 层级规则主键
     * @return 层级规则
     */
    @Override
    public HsSysLevel selectHsSysLevelById(String id)
    {
        return hsSysLevelMapper.selectHsSysLevelById(id);
    }

    @Override
    public Long getByMaxId(){
        return hsSysLevelMapper.getByMaxId();
 }

 @Override
    public Long getParent(String id){
        return hsSysLevelMapper.getParent(id);
 }
 @Override
    public Long getCode(String id){
        return hsSysLevelMapper.getCode(id);
 }


    /**
     * 查询层级规则列表
     *
     * @param hsSysLevel 层级规则
     * @return 层级规则
     */
    @Override
    public List<HsSysLevel> selectHsSysLevelList(HsSysLevel hsSysLevel)
    {
        return hsSysLevelMapper.selectHsSysLevelList(hsSysLevel);
    }

    /**
     * 新增层级规则
     *
     * @param hsSysLevel 层级规则
     * @return 结果
     */
    @Override
    public int insertHsSysLevel(HsSysLevel hsSysLevel)
    {
        return hsSysLevelMapper.insertHsSysLevel(hsSysLevel);
    }

    /**
     * 修改层级规则
     *
     * @param hsSysLevel 层级规则
     * @return 结果
     */
    @Override
    public int updateHsSysLevel(HsSysLevel hsSysLevel)
    {
        return hsSysLevelMapper.updateHsSysLevel(hsSysLevel);
    }

    /**
     * 批量删除层级规则
     *
     * @param ids 需要删除的层级规则主键
     * @return 结果
     */
    @Override
    public int deleteHsSysLevelByIds(String[] ids)
    {
        return hsSysLevelMapper.deleteHsSysLevelByIds(ids);
    }

    /**
     * 删除层级规则信息
     *
     * @param id 层级规则主键
     * @return 结果
     */
    @Override
    public int deleteHsSysLevelById(String id)
    {
        return hsSysLevelMapper.deleteHsSysLevelById(id);
    }
}
