import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'
import {queryOrganizationInfo, queryDeptInfo} from "@/api/system/dept";

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    roleTypes: [],
    organizations: [],
    organDicts: [],
    organ: '',
    depts: []
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },

    SET_ROLETYPES: (state, roleTypes) => {
      state.roleTypes = roleTypes
    },

    SET_ORGANIZATIONS: (state, organizations) => {
      state.organizations = organizations
    },

    SET_ORGANDICTS: (state, organDicts) => {
      state.organDicts = organDicts
    },

    SET_ORGAN: (state, organ) => {
      state.organ = organ
    },

    SET_DEPTS: (state,depts) =>{
      state.depts = depts
}
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.user
          localStorage.setItem('userName',user.userName)
          const avatar = user.avatar == "" ? require("@/assets/images/profile.jpg") : process.env.VUE_APP_BASE_API + user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
            commit('SET_ROLETYPES', res.roleTypes)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          if(res.organizations && res.organizations.length > 0) {
            commit('SET_ORGANIZATIONS', res.organizations)
          }
          commit('SET_ORGAN',res.organ);
          commit('SET_NAME', user.userName)
          commit('SET_AVATAR', avatar)
          resolve(res)
        }).catch(error => {
          reject(error)
        })

        queryOrganizationInfo().then(response => {
          if(response.data && response.data.length > 0) {
            commit('SET_ORGANDICTS', response.data)
          }
          resolve(response)
        }).catch(error => {
          reject(error)
        })

        queryDeptInfo().then(response => {
          if(response.data && response.data.length > 0) {
            commit('SET_DEPTS', response.data)
          }
          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          commit('SET_ROLETYPES', [])
          commit('SET_ORGANIZATIONS', [])
          commit('SET_ORGANDICTS', [])
          commit('SET_ORGAN','')
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
